
.. list-table::
   :header-rows: 1

   * - 
     - 
   * - ``/help intro``
     - the quickstart guide
   * - ``/help about``
     - about r0c
   * - ``/help commands``
     - list of commands
   * - ``/help hotkeys``
     - list of hotkeys

